@@ -23,6 +23,8 @@
 import logging
 import subprocess
 
+import netifaces
+
 from libcloud.common.types import LibcloudError
 
 from libcloudvagrant.tests import new_driver, sample_network, sample_node
@@ -33,6 +35,7 @@ __all__ = [
     "test_create_duplicate_netwoks",
     "test_destroy_network",
     "test_exhausted_networks",
+    "test_host_interface_cleanup",
     "test_list_networks",
     "test_overlapping_networks",
     "test_public_network",
@@ -77,7 +80,7 @@ def test_destroy_network():
     """Networks in use may not be destroyed.
 
     """
-    with sample_network("net1", cidr="192.168.0.0/24") as net1:
+    with sample_network("net1") as net1:
         with sample_node(networks=[net1]):
             assert not driver.ex_destroy_network(net1)
 
@@ -101,17 +104,36 @@ def test_exhausted_networks():
                                  (addr,))
 
 
+def test_host_interface_cleanup():
+    """Host interfaces are removed when their associated networks are
+    destroyed.
+
+    """
+    assert not any(i.startswith("vboxnet") for i in netifaces.interfaces())
+
+    with sample_network("pub", public=True) as pub:
+        with sample_node(networks=[pub]):
+            iface = pub.host_interface
+            assert iface in netifaces.interfaces()
+        assert iface in netifaces.interfaces()
+    assert iface not in netifaces.interfaces()
+
+    with sample_network("priv") as priv:
+        with sample_node(networks=[priv]):
+            assert priv.host_interface is None
+
+
 def test_list_networks():
     """Networks are listed properly.
 
     """
     assert len(driver.ex_list_networks()) == 0
-    with sample_network("net1", cidr="192.168.0.0/24") as net1:
+    with sample_network("net1") as net1:
         networks = driver.ex_list_networks()
         assert len(networks) == 1
         assert networks[0] == net1
 
-        with sample_network("net2", cidr="192.168.1.0/24") as net2:
+        with sample_network("net2") as net2:
             networks = driver.ex_list_networks()
             assert len(networks) == 2
             assert net1 in networks
@@ -147,7 +169,7 @@ def test_overlapping_networks():
 
 
 def test_public_network():
-    with sample_network("public", cidr="192.168.0.0/24", public=True) as pub:
+    with sample_network("public", public=True) as pub:
         with sample_node(networks=[pub]) as n:
             assert len(n.public_ips) == 1
             addr = n.public_ips[0]
@@ -161,9 +183,9 @@ def test_public_and_private_networks():
     not.
 
     """
-    pub = sample_network("public", cidr="192.168.0.0/24", public=True)
-    dmz = sample_network("dmz", cidr="192.168.1.0/24")
-    lan = sample_network("lan", cidr="192.168.3.0/24")
+    pub = sample_network("public", public=True)
+    dmz = sample_network("dmz")
+    lan = sample_network("lan")
 
     with pub as pub, dmz as dmz, lan as lan:
 
