@@ -44,9 +44,6 @@ LOG = logging.getLogger("liibcloudvagrant")
 
 def attach_volume(node_uuid, volume_path, device):
     controller, device, port = find_sata_slot(node_uuid, device)
-    vboxmanage("storagectl", node_uuid,
-               "--name", '"%s"' % (controller,),
-               "--portcount", port + 1)
     vboxmanage("storageattach", node_uuid,
                "--storagectl", '"%s"' % (controller,),
                "--port", port,
@@ -158,7 +155,7 @@ def find_sata_controllers(frag):
 
     for c in entries.values():
         ret.setdefault(c["type"], []).append(c["name"])
-    return ret.get("IntelAhci")
+    return ret.get("IntelAhci", [])
 
 
 _DEVICE_RE = re.compile(r"/dev/sd([a-z])")
